@@ -36,6 +36,22 @@ class DerbyGame:
                 self.team_color_1 = sns.color_palette()[0]
                 self.team_color_2 = sns.color_palette()[1]
 
+    def anonymize_team_names(self) -> None:
+        """Replace team names with "Team 1" and "Team 2"
+        """
+        self.game_data_dict["team_1"] = "Team 1"
+        self.game_data_dict["team_2"] = "Team 2"
+        name_replace_dict = {
+            self.team_1_name: "Team 1",
+            self.team_2_name: "Team 2",
+        }
+        self.pdf_jams_data = self.pdf_jams_data.replace(name_replace_dict)
+        self.pdf_penalties = self.pdf_penalties.replace(name_replace_dict)
+        self.pdf_team_colors = self.pdf_team_colors.replace(name_replace_dict)
+        self.team_1_name = "Team 1"
+        self.team_2_name = "Team 2"
+
+
     def set_team_color_1(self, acolor: str) -> None:
         if not is_color_like(acolor):
             raise ValueError(f"Invalid color specified: {acolor}")
@@ -78,12 +94,18 @@ class DerbyGame:
         final_score_team_1 = max(self.pdf_jams_data.TotalScore_1)
         final_score_team_2 = max(self.pdf_jams_data.TotalScore_2)
 
+        # Per @erevrav, injuries accrue to jams, not teams, so the proper quantity
+        # to represent at the game level is the number of jams that ended in injury.
+        n_jams_with_injury = sum(self.pdf_jams_data.Injury_1 |
+                                 self.pdf_jams_data.Injury_2)
+        
         gross_summary_dict = {
             "Periods": n_periods,
             "Jams": n_jams,
             "Total Game Time (min:sec)": time.strftime('%M:%S', time.gmtime(game_duration_s)),
             f"{self.team_1_name} Final Score": final_score_team_1,
             f"{self.team_2_name} Final Score": final_score_team_2,
+            "Injury Jams": n_jams_with_injury
         }
         return gross_summary_dict
 
@@ -96,9 +118,15 @@ class DerbyGame:
         Returns:
             pd.DataFrame: teams summary dataframe
         """
-        cols_to_sum = ["Lead", "Lost", "Calloff", "Injury", "NoInitial",
+        cols_to_sum = ["Lead", "Lost", "Calloff", "NoInitial",
                        "StarPass"]
         teams_summary_dict = {"Team": [self.team_1_name, self.team_2_name]}
+
+        # add skater counts
+        n_skaters_in_jams_1 = len(set().union(*self.pdf_jams_data.Skaters_1))
+        n_skaters_in_jams_2 = len(set().union(*self.pdf_jams_data.Skaters_2))
+        teams_summary_dict["Skaters played"] = [n_skaters_in_jams_1, n_skaters_in_jams_2]
+
         for col in cols_to_sum:
             sum_1 = sum(self.pdf_jams_data[col + "_1"])
             sum_2 = sum(self.pdf_jams_data[col + "_2"])
